def test_tumblr_gdpr():
    from reader._plugins.tumblr_gdpr import tumblr_gdpr

    # TODO: actually test the plugin
